==> itk-5.1.0-py38h32f6830_2.tar.bz2: Lib/site-packages/itk/Configuration/ITKAnisotropicSmoothingConfig.py <==
depends = ('ITKPyBase', 'ITKImageGrid', 'ITKCurvatureFlow', )
templates = (
  ('AnisotropicDiffusionImageFilter', 'itk::AnisotropicDiffusionImageFilter', 'itkAnisotropicDiffusionImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('AnisotropicDiffusionImageFilter', 'itk::AnisotropicDiffusionImageFilter', 'itkAnisotropicDiffusionImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('AnisotropicDiffusionImageFilter', 'itk::AnisotropicDiffusionImageFilter', 'itkAnisotropicDiffusionImageFilterID2ID2', True, 'itk::Image< double,2 >, itk::Image< double,2 >'),
  ('AnisotropicDiffusionImageFilter', 'itk::AnisotropicDiffusionImageFilter', 'itkAnisotropicDiffusionImageFilterID3ID3', True, 'itk::Image< double,3 >, itk::Image< double,3 >'),
  ('AnisotropicDiffusionImageFilter', 'itk::AnisotropicDiffusionImageFilter', 'itkAnisotropicDiffusionImageFilterIVF22IVF22', True, 'itk::Image< itk::Vector< float,2 >,2 >, itk::Image< itk::Vector< float,2 >,2 >'),
  ('AnisotropicDiffusionImageFilter', 'itk::AnisotropicDiffusionImageFilter', 'itkAnisotropicDiffusionImageFilterIVF23IVF23', True, 'itk::Image< itk::Vector< float,2 >,3 >, itk::Image< itk::Vector< float,2 >,3 >'),
  ('AnisotropicDiffusionImageFilter', 'itk::AnisotropicDiffusionImageFilter', 'itkAnisotropicDiffusionImageFilterIVF32IVF32', True, 'itk::Image< itk::Vector< float,3 >,2 >, itk::Image< itk::Vector< float,3 >,2 >'),
  ('AnisotropicDiffusionImageFilter', 'itk::AnisotropicDiffusionImageFilter', 'itkAnisotropicDiffusionImageFilterIVF33IVF33', True, 'itk::Image< itk::Vector< float,3 >,3 >, itk::Image< itk::Vector< float,3 >,3 >'),
  ('AnisotropicDiffusionImageFilter', 'itk::AnisotropicDiffusionImageFilter', 'itkAnisotropicDiffusionImageFilterIVF42IVF42', True, 'itk::Image< itk::Vector< float,4 >,2 >, itk::Image< itk::Vector< float,4 >,2 >'),
  ('AnisotropicDiffusionImageFilter', 'itk::AnisotropicDiffusionImageFilter', 'itkAnisotropicDiffusionImageFilterIVF43IVF43', True, 'itk::Image< itk::Vector< float,4 >,3 >, itk::Image< itk::Vector< float,4 >,3 >'),
  ('AnisotropicDiffusionImageFilter', 'itk::AnisotropicDiffusionImageFilter', 'itkAnisotropicDiffusionImageFilterICVF22ICVF22', True, 'itk::Image< itk::CovariantVector< float,2 >,2 >, itk::Image< itk::CovariantVector< float,2 >,2 >'),
  ('AnisotropicDiffusionImageFilter', 'itk::AnisotropicDiffusionImageFilter', 'itkAnisotropicDiffusionImageFilterICVF23ICVF23', True, 'itk::Image< itk::CovariantVector< float,2 >,3 >, itk::Image< itk::CovariantVector< float,2 >,3 >'),
  ('AnisotropicDiffusionImageFilter', 'itk::AnisotropicDiffusionImageFilter', 'itkAnisotropicDiffusionImageFilterICVF32ICVF32', True, 'itk::Image< itk::CovariantVector< float,3 >,2 >, itk::Image< itk::CovariantVector< float,3 >,2 >'),
  ('AnisotropicDiffusionImageFilter', 'itk::AnisotropicDiffusionImageFilter', 'itkAnisotropicDiffusionImageFilterICVF33ICVF33', True, 'itk::Image< itk::CovariantVector< float,3 >,3 >, itk::Image< itk::CovariantVector< float,3 >,3 >'),
  ('AnisotropicDiffusionImageFilter', 'itk::AnisotropicDiffusionImageFilter', 'itkAnisotropicDiffusionImageFilterICVF42ICVF42', True, 'itk::Image< itk::CovariantVector< float,4 >,2 >, itk::Image< itk::CovariantVector< float,4 >,2 >'),
  ('AnisotropicDiffusionImageFilter', 'itk::AnisotropicDiffusionImageFilter', 'itkAnisotropicDiffusionImageFilterICVF43ICVF43', True, 'itk::Image< itk::CovariantVector< float,4 >,3 >, itk::Image< itk::CovariantVector< float,4 >,3 >'),
  ('CurvatureAnisotropicDiffusionImageFilter', 'itk::CurvatureAnisotropicDiffusionImageFilter', 'itkCurvatureAnisotropicDiffusionImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('CurvatureAnisotropicDiffusionImageFilter', 'itk::CurvatureAnisotropicDiffusionImageFilter', 'itkCurvatureAnisotropicDiffusionImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('CurvatureAnisotropicDiffusionImageFilter', 'itk::CurvatureAnisotropicDiffusionImageFilter', 'itkCurvatureAnisotropicDiffusionImageFilterID2ID2', True, 'itk::Image< double,2 >, itk::Image< double,2 >'),
  ('CurvatureAnisotropicDiffusionImageFilter', 'itk::CurvatureAnisotropicDiffusionImageFilter', 'itkCurvatureAnisotropicDiffusionImageFilterID3ID3', True, 'itk::Image< double,3 >, itk::Image< double,3 >'),
  ('GradientAnisotropicDiffusionImageFilter', 'itk::GradientAnisotropicDiffusionImageFilter', 'itkGradientAnisotropicDiffusionImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('GradientAnisotropicDiffusionImageFilter', 'itk::GradientAnisotropicDiffusionImageFilter', 'itkGradientAnisotropicDiffusionImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('GradientAnisotropicDiffusionImageFilter', 'itk::GradientAnisotropicDiffusionImageFilter', 'itkGradientAnisotropicDiffusionImageFilterID2ID2', True, 'itk::Image< double,2 >, itk::Image< double,2 >'),
  ('GradientAnisotropicDiffusionImageFilter', 'itk::GradientAnisotropicDiffusionImageFilter', 'itkGradientAnisotropicDiffusionImageFilterID3ID3', True, 'itk::Image< double,3 >, itk::Image< double,3 >'),
  ('VectorCurvatureAnisotropicDiffusionImageFilter', 'itk::VectorCurvatureAnisotropicDiffusionImageFilter', 'itkVectorCurvatureAnisotropicDiffusionImageFilterIVF22IVF22', True, 'itk::Image< itk::Vector< float,2 >,2 >, itk::Image< itk::Vector< float,2 >,2 >'),
  ('VectorCurvatureAnisotropicDiffusionImageFilter', 'itk::VectorCurvatureAnisotropicDiffusionImageFilter', 'itkVectorCurvatureAnisotropicDiffusionImageFilterIVF23IVF23', True, 'itk::Image< itk::Vector< float,2 >,3 >, itk::Image< itk::Vector< float,2 >,3 >'),
  ('VectorCurvatureAnisotropicDiffusionImageFilter', 'itk::VectorCurvatureAnisotropicDiffusionImageFilter', 'itkVectorCurvatureAnisotropicDiffusionImageFilterIVF32IVF32', True, 'itk::Image< itk::Vector< float,3 >,2 >, itk::Image< itk::Vector< float,3 >,2 >'),
  ('VectorCurvatureAnisotropicDiffusionImageFilter', 'itk::VectorCurvatureAnisotropicDiffusionImageFilter', 'itkVectorCurvatureAnisotropicDiffusionImageFilterIVF33IVF33', True, 'itk::Image< itk::Vector< float,3 >,3 >, itk::Image< itk::Vector< float,3 >,3 >'),
  ('VectorCurvatureAnisotropicDiffusionImageFilter', 'itk::VectorCurvatureAnisotropicDiffusionImageFilter', 'itkVectorCurvatureAnisotropicDiffusionImageFilterIVF42IVF42', True, 'itk::Image< itk::Vector< float,4 >,2 >, itk::Image< itk::Vector< float,4 >,2 >'),
  ('VectorCurvatureAnisotropicDiffusionImageFilter', 'itk::VectorCurvatureAnisotropicDiffusionImageFilter', 'itkVectorCurvatureAnisotropicDiffusionImageFilterIVF43IVF43', True, 'itk::Image< itk::Vector< float,4 >,3 >, itk::Image< itk::Vector< float,4 >,3 >'),
  ('VectorCurvatureAnisotropicDiffusionImageFilter', 'itk::VectorCurvatureAnisotropicDiffusionImageFilter', 'itkVectorCurvatureAnisotropicDiffusionImageFilterICVF22ICVF22', True, 'itk::Image< itk::CovariantVector< float,2 >,2 >, itk::Image< itk::CovariantVector< float,2 >,2 >'),
  ('VectorCurvatureAnisotropicDiffusionImageFilter', 'itk::VectorCurvatureAnisotropicDiffusionImageFilter', 'itkVectorCurvatureAnisotropicDiffusionImageFilterICVF23ICVF23', True, 'itk::Image< itk::CovariantVector< float,2 >,3 >, itk::Image< itk::CovariantVector< float,2 >,3 >'),
  ('VectorCurvatureAnisotropicDiffusionImageFilter', 'itk::VectorCurvatureAnisotropicDiffusionImageFilter', 'itkVectorCurvatureAnisotropicDiffusionImageFilterICVF32ICVF32', True, 'itk::Image< itk::CovariantVector< float,3 >,2 >, itk::Image< itk::CovariantVector< float,3 >,2 >'),
  ('VectorCurvatureAnisotropicDiffusionImageFilter', 'itk::VectorCurvatureAnisotropicDiffusionImageFilter', 'itkVectorCurvatureAnisotropicDiffusionImageFilterICVF33ICVF33', True, 'itk::Image< itk::CovariantVector< float,3 >,3 >, itk::Image< itk::CovariantVector< float,3 >,3 >'),
  ('VectorCurvatureAnisotropicDiffusionImageFilter', 'itk::VectorCurvatureAnisotropicDiffusionImageFilter', 'itkVectorCurvatureAnisotropicDiffusionImageFilterICVF42ICVF42', True, 'itk::Image< itk::CovariantVector< float,4 >,2 >, itk::Image< itk::CovariantVector< float,4 >,2 >'),
  ('VectorCurvatureAnisotropicDiffusionImageFilter', 'itk::VectorCurvatureAnisotropicDiffusionImageFilter', 'itkVectorCurvatureAnisotropicDiffusionImageFilterICVF43ICVF43', True, 'itk::Image< itk::CovariantVector< float,4 >,3 >, itk::Image< itk::CovariantVector< float,4 >,3 >'),
  ('VectorGradientAnisotropicDiffusionImageFilter', 'itk::VectorGradientAnisotropicDiffusionImageFilter', 'itkVectorGradientAnisotropicDiffusionImageFilterIVF22IVF22', True, 'itk::Image< itk::Vector< float,2 >,2 >, itk::Image< itk::Vector< float,2 >,2 >'),
  ('VectorGradientAnisotropicDiffusionImageFilter', 'itk::VectorGradientAnisotropicDiffusionImageFilter', 'itkVectorGradientAnisotropicDiffusionImageFilterIVF23IVF23', True, 'itk::Image< itk::Vector< float,2 >,3 >, itk::Image< itk::Vector< float,2 >,3 >'),
  ('VectorGradientAnisotropicDiffusionImageFilter', 'itk::VectorGradientAnisotropicDiffusionImageFilter', 'itkVectorGradientAnisotropicDiffusionImageFilterIVF32IVF32', True, 'itk::Image< itk::Vector< float,3 >,2 >, itk::Image< itk::Vector< float,3 >,2 >'),
  ('VectorGradientAnisotropicDiffusionImageFilter', 'itk::VectorGradientAnisotropicDiffusionImageFilter', 'itkVectorGradientAnisotropicDiffusionImageFilterIVF33IVF33', True, 'itk::Image< itk::Vector< float,3 >,3 >, itk::Image< itk::Vector< float,3 >,3 >'),
  ('VectorGradientAnisotropicDiffusionImageFilter', 'itk::VectorGradientAnisotropicDiffusionImageFilter', 'itkVectorGradientAnisotropicDiffusionImageFilterIVF42IVF42', True, 'itk::Image< itk::Vector< float,4 >,2 >, itk::Image< itk::Vector< float,4 >,2 >'),
  ('VectorGradientAnisotropicDiffusionImageFilter', 'itk::VectorGradientAnisotropicDiffusionImageFilter', 'itkVectorGradientAnisotropicDiffusionImageFilterIVF43IVF43', True, 'itk::Image< itk::Vector< float,4 >,3 >, itk::Image< itk::Vector< float,4 >,3 >'),
  ('VectorGradientAnisotropicDiffusionImageFilter', 'itk::VectorGradientAnisotropicDiffusionImageFilter', 'itkVectorGradientAnisotropicDiffusionImageFilterICVF22ICVF22', True, 'itk::Image< itk::CovariantVector< float,2 >,2 >, itk::Image< itk::CovariantVector< float,2 >,2 >'),
  ('VectorGradientAnisotropicDiffusionImageFilter', 'itk::VectorGradientAnisotropicDiffusionImageFilter', 'itkVectorGradientAnisotropicDiffusionImageFilterICVF23ICVF23', True, 'itk::Image< itk::CovariantVector< float,2 >,3 >, itk::Image< itk::CovariantVector< float,2 >,3 >'),
  ('VectorGradientAnisotropicDiffusionImageFilter', 'itk::VectorGradientAnisotropicDiffusionImageFilter', 'itkVectorGradientAnisotropicDiffusionImageFilterICVF32ICVF32', True, 'itk::Image< itk::CovariantVector< float,3 >,2 >, itk::Image< itk::CovariantVector< float,3 >,2 >'),
  ('VectorGradientAnisotropicDiffusionImageFilter', 'itk::VectorGradientAnisotropicDiffusionImageFilter', 'itkVectorGradientAnisotropicDiffusionImageFilterICVF33ICVF33', True, 'itk::Image< itk::CovariantVector< float,3 >,3 >, itk::Image< itk::CovariantVector< float,3 >,3 >'),
  ('VectorGradientAnisotropicDiffusionImageFilter', 'itk::VectorGradientAnisotropicDiffusionImageFilter', 'itkVectorGradientAnisotropicDiffusionImageFilterICVF42ICVF42', True, 'itk::Image< itk::CovariantVector< float,4 >,2 >, itk::Image< itk::CovariantVector< float,4 >,2 >'),
  ('VectorGradientAnisotropicDiffusionImageFilter', 'itk::VectorGradientAnisotropicDiffusionImageFilter', 'itkVectorGradientAnisotropicDiffusionImageFilterICVF43ICVF43', True, 'itk::Image< itk::CovariantVector< float,4 >,3 >, itk::Image< itk::CovariantVector< float,4 >,3 >'),
)
snake_case_functions = ('vector_curvature_anisotropic_diffusion_image_filter', 'anisotropic_diffusion_image_filter', 'gradient_anisotropic_diffusion_image_filter', 'vector_gradient_anisotropic_diffusion_image_filter', 'curvature_anisotropic_diffusion_image_filter', )

==> itk-5.1.1-py38h32f6830_3.tar.bz2: Lib/site-packages/itk/Configuration/ITKAnisotropicSmoothingConfig.py <==
depends = ('ITKPyBase', 'ITKImageGrid', 'ITKCurvatureFlow', )
templates = (
  ('AnisotropicDiffusionImageFilter', 'itk::AnisotropicDiffusionImageFilter', 'itkAnisotropicDiffusionImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('AnisotropicDiffusionImageFilter', 'itk::AnisotropicDiffusionImageFilter', 'itkAnisotropicDiffusionImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('AnisotropicDiffusionImageFilter', 'itk::AnisotropicDiffusionImageFilter', 'itkAnisotropicDiffusionImageFilterID2ID2', True, 'itk::Image< double,2 >, itk::Image< double,2 >'),
  ('AnisotropicDiffusionImageFilter', 'itk::AnisotropicDiffusionImageFilter', 'itkAnisotropicDiffusionImageFilterID3ID3', True, 'itk::Image< double,3 >, itk::Image< double,3 >'),
  ('AnisotropicDiffusionImageFilter', 'itk::AnisotropicDiffusionImageFilter', 'itkAnisotropicDiffusionImageFilterIVF22IVF22', True, 'itk::Image< itk::Vector< float,2 >,2 >, itk::Image< itk::Vector< float,2 >,2 >'),
  ('AnisotropicDiffusionImageFilter', 'itk::AnisotropicDiffusionImageFilter', 'itkAnisotropicDiffusionImageFilterIVF23IVF23', True, 'itk::Image< itk::Vector< float,2 >,3 >, itk::Image< itk::Vector< float,2 >,3 >'),
  ('AnisotropicDiffusionImageFilter', 'itk::AnisotropicDiffusionImageFilter', 'itkAnisotropicDiffusionImageFilterIVF32IVF32', True, 'itk::Image< itk::Vector< float,3 >,2 >, itk::Image< itk::Vector< float,3 >,2 >'),
  ('AnisotropicDiffusionImageFilter', 'itk::AnisotropicDiffusionImageFilter', 'itkAnisotropicDiffusionImageFilterIVF33IVF33', True, 'itk::Image< itk::Vector< float,3 >,3 >, itk::Image< itk::Vector< float,3 >,3 >'),
  ('AnisotropicDiffusionImageFilter', 'itk::AnisotropicDiffusionImageFilter', 'itkAnisotropicDiffusionImageFilterIVF42IVF42', True, 'itk::Image< itk::Vector< float,4 >,2 >, itk::Image< itk::Vector< float,4 >,2 >'),
  ('AnisotropicDiffusionImageFilter', 'itk::AnisotropicDiffusionImageFilter', 'itkAnisotropicDiffusionImageFilterIVF43IVF43', True, 'itk::Image< itk::Vector< float,4 >,3 >, itk::Image< itk::Vector< float,4 >,3 >'),
  ('AnisotropicDiffusionImageFilter', 'itk::AnisotropicDiffusionImageFilter', 'itkAnisotropicDiffusionImageFilterICVF22ICVF22', True, 'itk::Image< itk::CovariantVector< float,2 >,2 >, itk::Image< itk::CovariantVector< float,2 >,2 >'),
  ('AnisotropicDiffusionImageFilter', 'itk::AnisotropicDiffusionImageFilter', 'itkAnisotropicDiffusionImageFilterICVF23ICVF23', True, 'itk::Image< itk::CovariantVector< float,2 >,3 >, itk::Image< itk::CovariantVector< float,2 >,3 >'),
  ('AnisotropicDiffusionImageFilter', 'itk::AnisotropicDiffusionImageFilter', 'itkAnisotropicDiffusionImageFilterICVF32ICVF32', True, 'itk::Image< itk::CovariantVector< float,3 >,2 >, itk::Image< itk::CovariantVector< float,3 >,2 >'),
  ('AnisotropicDiffusionImageFilter', 'itk::AnisotropicDiffusionImageFilter', 'itkAnisotropicDiffusionImageFilterICVF33ICVF33', True, 'itk::Image< itk::CovariantVector< float,3 >,3 >, itk::Image< itk::CovariantVector< float,3 >,3 >'),
  ('AnisotropicDiffusionImageFilter', 'itk::AnisotropicDiffusionImageFilter', 'itkAnisotropicDiffusionImageFilterICVF42ICVF42', True, 'itk::Image< itk::CovariantVector< float,4 >,2 >, itk::Image< itk::CovariantVector< float,4 >,2 >'),
  ('AnisotropicDiffusionImageFilter', 'itk::AnisotropicDiffusionImageFilter', 'itkAnisotropicDiffusionImageFilterICVF43ICVF43', True, 'itk::Image< itk::CovariantVector< float,4 >,3 >, itk::Image< itk::CovariantVector< float,4 >,3 >'),
  ('CurvatureAnisotropicDiffusionImageFilter', 'itk::CurvatureAnisotropicDiffusionImageFilter', 'itkCurvatureAnisotropicDiffusionImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('CurvatureAnisotropicDiffusionImageFilter', 'itk::CurvatureAnisotropicDiffusionImageFilter', 'itkCurvatureAnisotropicDiffusionImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('CurvatureAnisotropicDiffusionImageFilter', 'itk::CurvatureAnisotropicDiffusionImageFilter', 'itkCurvatureAnisotropicDiffusionImageFilterID2ID2', True, 'itk::Image< double,2 >, itk::Image< double,2 >'),
  ('CurvatureAnisotropicDiffusionImageFilter', 'itk::CurvatureAnisotropicDiffusionImageFilter', 'itkCurvatureAnisotropicDiffusionImageFilterID3ID3', True, 'itk::Image< double,3 >, itk::Image< double,3 >'),
  ('GradientAnisotropicDiffusionImageFilter', 'itk::GradientAnisotropicDiffusionImageFilter', 'itkGradientAnisotropicDiffusionImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('GradientAnisotropicDiffusionImageFilter', 'itk::GradientAnisotropicDiffusionImageFilter', 'itkGradientAnisotropicDiffusionImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('GradientAnisotropicDiffusionImageFilter', 'itk::GradientAnisotropicDiffusionImageFilter', 'itkGradientAnisotropicDiffusionImageFilterID2ID2', True, 'itk::Image< double,2 >, itk::Image< double,2 >'),
  ('GradientAnisotropicDiffusionImageFilter', 'itk::GradientAnisotropicDiffusionImageFilter', 'itkGradientAnisotropicDiffusionImageFilterID3ID3', True, 'itk::Image< double,3 >, itk::Image< double,3 >'),
  ('VectorCurvatureAnisotropicDiffusionImageFilter', 'itk::VectorCurvatureAnisotropicDiffusionImageFilter', 'itkVectorCurvatureAnisotropicDiffusionImageFilterIVF22IVF22', True, 'itk::Image< itk::Vector< float,2 >,2 >, itk::Image< itk::Vector< float,2 >,2 >'),
  ('VectorCurvatureAnisotropicDiffusionImageFilter', 'itk::VectorCurvatureAnisotropicDiffusionImageFilter', 'itkVectorCurvatureAnisotropicDiffusionImageFilterIVF23IVF23', True, 'itk::Image< itk::Vector< float,2 >,3 >, itk::Image< itk::Vector< float,2 >,3 >'),
  ('VectorCurvatureAnisotropicDiffusionImageFilter', 'itk::VectorCurvatureAnisotropicDiffusionImageFilter', 'itkVectorCurvatureAnisotropicDiffusionImageFilterIVF32IVF32', True, 'itk::Image< itk::Vector< float,3 >,2 >, itk::Image< itk::Vector< float,3 >,2 >'),
  ('VectorCurvatureAnisotropicDiffusionImageFilter', 'itk::VectorCurvatureAnisotropicDiffusionImageFilter', 'itkVectorCurvatureAnisotropicDiffusionImageFilterIVF33IVF33', True, 'itk::Image< itk::Vector< float,3 >,3 >, itk::Image< itk::Vector< float,3 >,3 >'),
  ('VectorCurvatureAnisotropicDiffusionImageFilter', 'itk::VectorCurvatureAnisotropicDiffusionImageFilter', 'itkVectorCurvatureAnisotropicDiffusionImageFilterIVF42IVF42', True, 'itk::Image< itk::Vector< float,4 >,2 >, itk::Image< itk::Vector< float,4 >,2 >'),
  ('VectorCurvatureAnisotropicDiffusionImageFilter', 'itk::VectorCurvatureAnisotropicDiffusionImageFilter', 'itkVectorCurvatureAnisotropicDiffusionImageFilterIVF43IVF43', True, 'itk::Image< itk::Vector< float,4 >,3 >, itk::Image< itk::Vector< float,4 >,3 >'),
  ('VectorCurvatureAnisotropicDiffusionImageFilter', 'itk::VectorCurvatureAnisotropicDiffusionImageFilter', 'itkVectorCurvatureAnisotropicDiffusionImageFilterICVF22ICVF22', True, 'itk::Image< itk::CovariantVector< float,2 >,2 >, itk::Image< itk::CovariantVector< float,2 >,2 >'),
  ('VectorCurvatureAnisotropicDiffusionImageFilter', 'itk::VectorCurvatureAnisotropicDiffusionImageFilter', 'itkVectorCurvatureAnisotropicDiffusionImageFilterICVF23ICVF23', True, 'itk::Image< itk::CovariantVector< float,2 >,3 >, itk::Image< itk::CovariantVector< float,2 >,3 >'),
  ('VectorCurvatureAnisotropicDiffusionImageFilter', 'itk::VectorCurvatureAnisotropicDiffusionImageFilter', 'itkVectorCurvatureAnisotropicDiffusionImageFilterICVF32ICVF32', True, 'itk::Image< itk::CovariantVector< float,3 >,2 >, itk::Image< itk::CovariantVector< float,3 >,2 >'),
  ('VectorCurvatureAnisotropicDiffusionImageFilter', 'itk::VectorCurvatureAnisotropicDiffusionImageFilter', 'itkVectorCurvatureAnisotropicDiffusionImageFilterICVF33ICVF33', True, 'itk::Image< itk::CovariantVector< float,3 >,3 >, itk::Image< itk::CovariantVector< float,3 >,3 >'),
  ('VectorCurvatureAnisotropicDiffusionImageFilter', 'itk::VectorCurvatureAnisotropicDiffusionImageFilter', 'itkVectorCurvatureAnisotropicDiffusionImageFilterICVF42ICVF42', True, 'itk::Image< itk::CovariantVector< float,4 >,2 >, itk::Image< itk::CovariantVector< float,4 >,2 >'),
  ('VectorCurvatureAnisotropicDiffusionImageFilter', 'itk::VectorCurvatureAnisotropicDiffusionImageFilter', 'itkVectorCurvatureAnisotropicDiffusionImageFilterICVF43ICVF43', True, 'itk::Image< itk::CovariantVector< float,4 >,3 >, itk::Image< itk::CovariantVector< float,4 >,3 >'),
  ('VectorGradientAnisotropicDiffusionImageFilter', 'itk::VectorGradientAnisotropicDiffusionImageFilter', 'itkVectorGradientAnisotropicDiffusionImageFilterIVF22IVF22', True, 'itk::Image< itk::Vector< float,2 >,2 >, itk::Image< itk::Vector< float,2 >,2 >'),
  ('VectorGradientAnisotropicDiffusionImageFilter', 'itk::VectorGradientAnisotropicDiffusionImageFilter', 'itkVectorGradientAnisotropicDiffusionImageFilterIVF23IVF23', True, 'itk::Image< itk::Vector< float,2 >,3 >, itk::Image< itk::Vector< float,2 >,3 >'),
  ('VectorGradientAnisotropicDiffusionImageFilter', 'itk::VectorGradientAnisotropicDiffusionImageFilter', 'itkVectorGradientAnisotropicDiffusionImageFilterIVF32IVF32', True, 'itk::Image< itk::Vector< float,3 >,2 >, itk::Image< itk::Vector< float,3 >,2 >'),
  ('VectorGradientAnisotropicDiffusionImageFilter', 'itk::VectorGradientAnisotropicDiffusionImageFilter', 'itkVectorGradientAnisotropicDiffusionImageFilterIVF33IVF33', True, 'itk::Image< itk::Vector< float,3 >,3 >, itk::Image< itk::Vector< float,3 >,3 >'),
  ('VectorGradientAnisotropicDiffusionImageFilter', 'itk::VectorGradientAnisotropicDiffusionImageFilter', 'itkVectorGradientAnisotropicDiffusionImageFilterIVF42IVF42', True, 'itk::Image< itk::Vector< float,4 >,2 >, itk::Image< itk::Vector< float,4 >,2 >'),
  ('VectorGradientAnisotropicDiffusionImageFilter', 'itk::VectorGradientAnisotropicDiffusionImageFilter', 'itkVectorGradientAnisotropicDiffusionImageFilterIVF43IVF43', True, 'itk::Image< itk::Vector< float,4 >,3 >, itk::Image< itk::Vector< float,4 >,3 >'),
  ('VectorGradientAnisotropicDiffusionImageFilter', 'itk::VectorGradientAnisotropicDiffusionImageFilter', 'itkVectorGradientAnisotropicDiffusionImageFilterICVF22ICVF22', True, 'itk::Image< itk::CovariantVector< float,2 >,2 >, itk::Image< itk::CovariantVector< float,2 >,2 >'),
  ('VectorGradientAnisotropicDiffusionImageFilter', 'itk::VectorGradientAnisotropicDiffusionImageFilter', 'itkVectorGradientAnisotropicDiffusionImageFilterICVF23ICVF23', True, 'itk::Image< itk::CovariantVector< float,2 >,3 >, itk::Image< itk::CovariantVector< float,2 >,3 >'),
  ('VectorGradientAnisotropicDiffusionImageFilter', 'itk::VectorGradientAnisotropicDiffusionImageFilter', 'itkVectorGradientAnisotropicDiffusionImageFilterICVF32ICVF32', True, 'itk::Image< itk::CovariantVector< float,3 >,2 >, itk::Image< itk::CovariantVector< float,3 >,2 >'),
  ('VectorGradientAnisotropicDiffusionImageFilter', 'itk::VectorGradientAnisotropicDiffusionImageFilter', 'itkVectorGradientAnisotropicDiffusionImageFilterICVF33ICVF33', True, 'itk::Image< itk::CovariantVector< float,3 >,3 >, itk::Image< itk::CovariantVector< float,3 >,3 >'),
  ('VectorGradientAnisotropicDiffusionImageFilter', 'itk::VectorGradientAnisotropicDiffusionImageFilter', 'itkVectorGradientAnisotropicDiffusionImageFilterICVF42ICVF42', True, 'itk::Image< itk::CovariantVector< float,4 >,2 >, itk::Image< itk::CovariantVector< float,4 >,2 >'),
  ('VectorGradientAnisotropicDiffusionImageFilter', 'itk::VectorGradientAnisotropicDiffusionImageFilter', 'itkVectorGradientAnisotropicDiffusionImageFilterICVF43ICVF43', True, 'itk::Image< itk::CovariantVector< float,4 >,3 >, itk::Image< itk::CovariantVector< float,4 >,3 >'),
)
snake_case_functions = ('curvature_anisotropic_diffusion_image_filter', 'vector_curvature_anisotropic_diffusion_image_filter', 'vector_gradient_anisotropic_diffusion_image_filter', 'anisotropic_diffusion_image_filter', 'gradient_anisotropic_diffusion_image_filter', )
